///File : DataManager.hpp
//------------------------------------------------------------------------------
/*
    This file is part of LCDnurse.

    LCDnurse is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    LCDnurse is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with LCDnurse.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#ifndef DATA_MANAGER_HPP_LCD_NURSE
#define DATA_MANAGER_HPP_LCD_NURSE
//------------------------------------------------------------------------------
#include <string>
#include <vector>
#include <iostream>
#include <fstream>
#include <sstream>
//------------------------------------------------------------------------------
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif
//------------------------------------------------------------------------------
#define COLORS_NAME_LIST COLORS_NAME_LIST_NO_BLACK, _("Black")
#define COLORS_LIST_SIZE 5

#define COLORS_NAME_LIST_NO_BLACK _("Red"), _("Green"), _("Blue"), _("White")
#define COLORS_LIST_NO_BLACK_SIZE 4

#define RED_CODE 0
#define GREEN_CODE 1
#define BLUE_CODE 2
#define WHITE_CODE 3
#define BLACK_CODE 4
//------------------------------------------------------------------------------
// Str to nb / nb to str
std::string intToString(int nb);
int stringToInt(std::string nbStr);
float stringToFloat(std::string nbStr);
std::string floatToString(float nb);
//------------------------------------------------------------------------------

struct RectStr
{
    wxRect rect;
    char color;
};
//------------------------------------------------------------------------------
class DataManager
{
public:
    DataManager();
    bool LoadCfg();
    bool SaveCfg();

    void FindStandardPaths();

    std::vector<RectStr> GetRects() const;
    bool DeleteRect(const wxPoint &pos, wxRect &deletedRect);
    void ClearRects();
    void AddRect(const wxRect &rect, const char &color);
    size_t GetRectCount() const;

    char GetBackgroundColor() const;
    void SetBackgroundColor(const char &color);
    void PreviousBackgroundColor();
    void NextBackgroundColor();

    int GetFrequence() const;
    void SetFrequence(const int &frequence);

    int GetPeriod() const;
    void SetPeriod(const int &period);

    bool IsFileChanged();

private:
    std::string m_filename;

    char m_backgroundColor;

    std::vector<RectStr> m_Rects;

    bool m_fileChanged;
    int m_frequence;
};

#endif // DATA_MANAGER_HPP_LCD_NURSE
